@@ -1,16 +1,17 @@
 package CLI::MetaUtil::Getopt::Long;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-12-01'; # DATE
-our $DIST = 'CLI-MetaUtil-Getopt-Long'; # DIST
-our $VERSION = '0.002'; # VERSION
-
 use strict 'subs', 'vars';
 use warnings;
 
 use Getopt::Long ();
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-10-07'; # DATE
+our $DIST = 'CLI-MetaUtil-Getopt-Long'; # DIST
+our $VERSION = '0.003'; # VERSION
+
 our @EXPORT_OK = qw(GetOptionsCLIWrapper);
 our %SPEC;
 
@@ -84,7 +85,7 @@ CLI::MetaUtil::Getopt::Long - Routine related to Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.002 of CLI::MetaUtil::Getopt::Long (from Perl distribution CLI-MetaUtil-Getopt-Long), released on 2020-12-01.
+This document describes version 0.003 of CLI::MetaUtil::Getopt::Long (from Perl distribution CLI-MetaUtil-Getopt-Long), released on 2022-10-07.
 
 =head1 SYNOPSIS
 
@@ -127,6 +128,39 @@ Please visit the project's homepage at L<https://metacpan.org/release/CLI-MetaUt
 
 Source repository is at L<https://github.com/perlancar/perl-CLI-MetaUtil-Getopt-Long>.
 
+=head1 SEE ALSO
+
+L<CLI::MetaUtil::Getopt::Long::Complete>
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=CLI-MetaUtil-Getopt-Long>
@@ -135,15 +169,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
